@@ -3,8 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 4,
- 'ALIGNOF_SIZE_T': 4,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -22,25 +22,26 @@ build_time_vars = {'ABIFLAGS': '',
               '-Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'powerpc--netbsd',
+ 'BUILD_GNU_TYPE': 'sparc64--netbsd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-           '-I/usr/include -I/usr/pkg/include',
+           '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+           '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+           '-I/usr/pkg/include -Dz_off_t=long',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
@@ -49,25 +50,26 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-readline=readline' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
                 "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=powerpc--netbsd' '--host=powerpc--netbsd' "
+                "'--build=sparc64--netbsd' '--host=sparc64--netbsd' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=powerpc--netbsd' 'host_alias=powerpc--netbsd' "
-                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
-                "'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
-                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
-                "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
-                "'PKG_CONFIG=/usr/pkgsrc/lang/python310/work/.tools/bin/pkg-config' "
+                "'build_alias=sparc64--netbsd' 'host_alias=sparc64--netbsd' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include "
+                "-Dz_off_t=long' 'LDFLAGS=-Wl,-zrelro -L/usr/lib "
+                '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+                "-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/usr/pkg/include -Dz_off_t=long' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python310/work.sparc64/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python310/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python310/work/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python310/work.sparc64/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python310/work.sparc64/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/pkgsrc/lang/python310/work/Python-3.10.18/coverage.info',
- 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python310/work/Python-3.10.18/lcov-report',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19/coverage.info',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
-             '-I/usr/pkg/include',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+             '-I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'CXX': 'c++ -pthread',
  'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.10 '
              '/usr/pkg/lib/python3.10/lib-dynload',
@@ -229,7 +231,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -280,7 +282,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -541,7 +543,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'powerpc--netbsd',
+ 'HOST_GNU_TYPE': 'sparc64--netbsd',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.10 /usr/pkg/include/python3.10',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -631,7 +633,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -666,39 +668,43 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -std=gnu99 '
+                             '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+                             '-O2 -I/usr/include -I/usr/pkg/include '
+                             '-Dz_off_t=long -O2 -I/usr/include '
+                             '-I/usr/pkg/include -Dz_off_t=long -std=gnu99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/pkg/include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-Dz_off_t=long -I/usr/include -I/usr/pkg/include '
+                             '-Dz_off_t=long -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-              '-I/usr/include -I/usr/pkg/include',
+              '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+              '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+              '-I/usr/pkg/include -Dz_off_t=long',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
                    '-std=gnu99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
-                   '-DPy_BUILD_CORE',
+                   '-I/usr/pkg/include -Dz_off_t=long -I/usr/include '
+                   '-I/usr/pkg/include -Dz_off_t=long -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-                '-I/usr/include -I/usr/pkg/include',
+                '-Dz_off_t=long -I/usr/include -I/usr/pkg/include '
+                '-Dz_off_t=long',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
@@ -709,15 +715,16 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/pkg/include -std=gnu99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                        '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                        '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+                        '-std=gnu99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/include -I/usr/pkg/include -fPIC',
+                        '-Dz_off_t=long -I/usr/include -I/usr/pkg/include '
+                        '-Dz_off_t=long -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -726,7 +733,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python310/work/Python-3.10.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -739,18 +746,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-310',
@@ -768,10 +775,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python310/work/Python-3.10.18 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python310/work/Python-3.10.18 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -799,8 +806,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/pkgsrc/lang/python310/work/Python-3.10.18',
- 'abs_srcdir': '/usr/pkgsrc/lang/python310/work/Python-3.10.18',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python310/work.sparc64/Python-3.10.19',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
