@@ -3,8 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -15,14 +15,16 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/pkg/bin',
  'BINLIBDEST': '/usr/pkg/lib/python3.10',
  'BLDLIBRARY': '-L. -lpython3.10',
- 'BLDSHARED': 'gcc -pthread -shared -L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+ 'BLDSHARED': 'gcc -pthread -shared -L. -Wl,-zrelro '
+              '-Wl,-z,common-page-size=0x10000 -L/usr/lib -Wl,-R/usr/lib '
               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-              '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+              '-Wl,-R/usr/X11R7/lib -Wl,-zrelro '
+              '-Wl,-z,common-page-size=0x10000 -L/usr/lib -Wl,-R/usr/lib '
               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
               '-Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'aarch64--netbsd',
+ 'BUILD_GNU_TYPE': 'mips64--netbsd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
@@ -41,29 +43,30 @@ build_time_vars = {'ABIFLAGS': '',
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
- 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-                      '-Wl,-R/usr/X11R7/lib',
+ 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -Wl,-z,common-page-size=0x10000 -L/usr/lib '
+                      '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+                      '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' "
                 "'--with-readline=readline' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
                 "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=aarch64--netbsd' '--host=aarch64--netbsd' "
+                "'--build=mips64--netbsd' '--host=mips64--netbsd' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=aarch64--netbsd' 'host_alias=aarch64--netbsd' "
+                "'build_alias=mips64--netbsd' 'host_alias=mips64--netbsd' "
                 "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
-                "'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
-                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
-                "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
-                "'PKG_CONFIG=/pbulk/work/lang/python310/work/.tools/bin/pkg-config' "
+                "'LDFLAGS=-Wl,-zrelro -Wl,-z,common-page-size=0x10000 "
+                '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+                "-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python310/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/pbulk/work/lang/python310/work/.buildlink/lib/pkgconfig:/pbulk/work/lang/python310/work/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python310/work/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python310/work/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pbulk/work/lang/python310/work/Python-3.10.18/coverage.info',
- 'COVERAGE_REPORT': '/pbulk/work/lang/python310/work/Python-3.10.18/lcov-report',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python310/work/Python-3.10.19/coverage.info',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python310/work/Python-3.10.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -84,8 +87,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -102,7 +105,7 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
+ 'FLOAT_WORDS_BIGENDIAN': 1,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GITBRANCH': '',
@@ -280,7 +283,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -541,7 +544,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'aarch64--netbsd',
+ 'HOST_GNU_TYPE': 'mips64--netbsd',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.10 /usr/pkg/include/python3.10',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -555,18 +558,20 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
- 'LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-            '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS': '-L. -Wl,-zrelro -Wl,-z,common-page-size=0x10000 -L/usr/lib '
+            '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+            '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -Wl,-z,common-page-size=0x10000 '
+            '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+            '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+ 'LDSHARED': 'gcc -pthread -shared -L. -Wl,-zrelro '
+             '-Wl,-z,common-page-size=0x10000 -L/usr/lib -Wl,-R/usr/lib '
              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-             '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
-             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-             '-Wl,-R/usr/X11R7/lib',
+             '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -Wl,-z,common-page-size=0x10000 '
+             '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDVERSION': '3.10',
  'LIBC': '',
  'LIBDEST': '/usr/pkg/lib/python3.10',
@@ -693,18 +698,22 @@ build_time_vars = {'ABIFLAGS': '',
                    '-I./Include/internal -I. -I./Include -I/usr/include '
                    '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -Wl,-z,common-page-size=0x10000 '
+                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                    '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+                    '-Wl,-zrelro -Wl,-z,common-page-size=0x10000 -L/usr/lib '
+                    '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+                    '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
                 '-I/usr/include -I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-               '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'PY_LDFLAGS': '-L. -Wl,-zrelro -Wl,-z,common-page-size=0x10000 -L/usr/lib '
+               '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+               '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -Wl,-zrelro '
+               '-Wl,-z,common-page-size=0x10000 -L/usr/lib -Wl,-R/usr/lib '
+               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+               '-Wl,-R/usr/X11R7/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
@@ -726,7 +735,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/pbulk/work/lang/python310/work/Python-3.10.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work/Python-3.10.19',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -739,18 +748,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG': 4,
  'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-310',
@@ -768,10 +777,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/pbulk/work/lang/python310/work/Python-3.10.18 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work/Python-3.10.19 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/pbulk/work/lang/python310/work/Python-3.10.18 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work/Python-3.10.19 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -799,8 +808,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pbulk/work/lang/python310/work/Python-3.10.18',
- 'abs_srcdir': '/pbulk/work/lang/python310/work/Python-3.10.18',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python310/work/Python-3.10.19',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python310/work/Python-3.10.19',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
